@@ -7,16 +7,7 @@
 #include "math.h"
 
 
-static QString timeNames[7];/* = {
- 'Fajr',
- 'Sunrise',
- 'Dhuhr',
- 'Asr',
- 'Sunset',
- 'Maghrib',
- 'Isha'
- };
- */
+
 QString InvalidTime;// = '-----';	 // The string used for invalid times
 
 
@@ -41,12 +32,6 @@ float resultArray[7];
 QString stringArray[7];
 
 
-//--------------------- Technical Settings --------------------
-
-
-int numIterations;// = 1;		// number of iterations needed to compute times
-
-
 //------------------- Calc Method Parameters --------------------
 
 
@@ -445,8 +430,3 @@ CalculationMethod calculationMethod;
         QString * PrayTime::getPrayTimesArray(){
             return stringArray;
         }
-
-        /*PrayTime::~PrayTime(){
-            delete(stringArray);
-        }*/
-
