@@ -185,7 +185,7 @@ void adjustTimesFormat(float times[]);
 void computeDayTimes();
 
 // adjust Fajr, Isha and Maghrib for locations in higher latitudes
-float * adjustHighLatTimes(float times[]);
+void adjustHighLatTimes(float times[]);
 
 // the night portion used for adjusting times in higher latitudes
 float nightPortion(float angle);
