@@ -22,6 +22,8 @@ public:
 public slots:
     void showOptions();
     void showAbout();
+    void showAlarmTimes();
+    void testAzanAlarm();
 
 protected:
     void changeEvent(QEvent *e);
