@@ -15,6 +15,26 @@ OptionsDialog::OptionsDialog(QWidget *parent) :
         this->ui->calcMethoBox->setCurrentIndex(settings.getCalcMethod());
         this->ui->jMethodBox->setCurrentIndex(settings.getJuristicMethod());
         this->ui->latMethodBox->setCurrentIndex(settings.getLatMethod());
+        this->ui->chkAsr->setChecked(settings.getAsrEnabled());
+        this->ui->chkFagr->setChecked(settings.getFagrEnabled());
+        this->ui->chkIsha->setChecked(settings.getIshaEnabled());
+        this->ui->chkMagrib->setChecked(settings.getMagribEnabled());
+        this->ui->chkZuhr->setChecked(settings.getZuhrEnabled());
+        this->ui->spinFagrA->setValue(settings.getFagrAMargin());
+        this->ui->spinZuhrA->setValue(settings.getZuhrAMargin());
+        this->ui->spinAsrA->setValue(settings.getAsrAMargin());
+        this->ui->spinMagribA->setValue(settings.getMagribAMargin());
+        this->ui->spinIshaaA->setValue(settings.getIshaAMargin());
+        this->ui->spinFagrI->setValue(settings.getFagrIMargin());
+        this->ui->spinZuhrI->setValue(settings.getZuhrIMargin());
+        this->ui->spinAsrI->setValue(settings.getAsrIMargin());
+        this->ui->spinMagribI->setValue(settings.getMagribIMargin());
+        this->ui->spinIshaaI->setValue(settings.getIshaIMargin());
+        this->ui->spinFagrS->setValue(settings.getFagrSPeriod());
+        this->ui->spinZuhrS->setValue(settings.getZuhrSPeriod());
+        this->ui->spinAsrS->setValue(settings.getAsrSPeriod());
+        this->ui->spinMagribS->setValue(settings.getMagribSPeriod());
+        this->ui->spinIshaaS->setValue(settings.getIshaSPeriod());
     }
 }
 
@@ -69,6 +89,17 @@ void OptionsDialog::changeEvent(QEvent *e)
 void OptionsDialog::saveClickedHandler(){
     settings.update(ui->latLineEdit->text(), ui->longLineEdit->text(),ui->tzLineEdit->text(),ui->calcMethoBox->currentIndex(),
                     ui->jMethodBox->currentIndex(), ui->latMethodBox->currentIndex(),ui->timeFormatBox->currentIndex());
+    settings.updateAzanSettings(
+        //individual azans
+        ui->chkFagr->isChecked(),ui->chkZuhr->isChecked(),ui->chkAsr->isChecked(),ui->chkMagrib->isChecked(),ui->chkIsha->isChecked(),
+        //azan margin (can be +ve or -ve)
+        ui->spinFagrA->value(),ui->spinZuhrA->value(),ui->spinAsrA->value(),ui->spinMagribA->value(),ui->spinIshaaA->value(),
+        //ikama margin (can be +ve or -ve)
+        ui->spinFagrI->value(),ui->spinZuhrI->value(),ui->spinAsrI->value(),ui->spinMagribI->value(),ui->spinIshaaI->value(),
+        //silent period
+        ui->spinFagrS->value(),ui->spinZuhrS->value(),ui->spinAsrS->value(),ui->spinMagribS->value(),ui->spinIshaaS->value());
+
+
     this->accept();
 }
 
